# LibreSVIP

LibreSVIP is a cross-platform and universal converter for many Singing Voice Synthesis (SVS) project formats,
which is highly inspired by following projects:

- [OpenSVIP] (link: https://github.com/yqzhishen/opensvip)
- [Utaformatix3] (link: https://github.com/sdercolin/utaformatix3)

Other projects that are related to this project:

- [QNrbf] (link: https://github.com/SineStriker/QNrbf)